@@ -1,5 +1,7 @@
+import os
 
-__version__='0.0.1'
+__version__='0.0.5'
+__path__=os.path.abspath(os.getcwd())
 
 def parse_version_info(version_str):
     version_info = []
